==> knative-model-5.1.1-sources.jar: annotations/io/fabric8/knative/sources/v1beta1/PingSourceSpecFluent.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.StringBuffer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverrides;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesFluent;
import java.lang.Object;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesBuilder;
import java.lang.Boolean;
import java.util.Map;

public interface PingSourceSpecFluent<A extends PingSourceSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildCeOverrides instead.
 * @return The buildable object.
 */
@Deprecated public CloudEventOverrides getCeOverrides();
    public CloudEventOverrides buildCeOverrides();
    public A withCeOverrides(CloudEventOverrides ceOverrides);
    public Boolean hasCeOverrides();
    public PingSourceSpecFluent.CeOverridesNested<A> withNewCeOverrides();
    public PingSourceSpecFluent.CeOverridesNested<A> withNewCeOverridesLike(CloudEventOverrides item);
    public PingSourceSpecFluent.CeOverridesNested<A> editCeOverrides();
    public PingSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverrides();
    public PingSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverridesLike(CloudEventOverrides item);
    public String getJsonData();
    public A withJsonData(String jsonData);
    public Boolean hasJsonData();
    public A withNewJsonData(String arg1);
    public A withNewJsonData(StringBuilder arg1);
    public A withNewJsonData(StringBuffer arg1);
    public String getSchedule();
    public A withSchedule(String schedule);
    public Boolean hasSchedule();
    public A withNewSchedule(String arg1);
    public A withNewSchedule(StringBuilder arg1);
    public A withNewSchedule(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getSink();
    public Destination buildSink();
    public A withSink(Destination sink);
    public Boolean hasSink();
    public PingSourceSpecFluent.SinkNested<A> withNewSink();
    public PingSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
    public PingSourceSpecFluent.SinkNested<A> editSink();
    public PingSourceSpecFluent.SinkNested<A> editOrNewSink();
    public PingSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
    public String getTimezone();
    public A withTimezone(String timezone);
    public Boolean hasTimezone();
    public A withNewTimezone(String arg1);
    public A withNewTimezone(StringBuilder arg1);
    public A withNewTimezone(StringBuffer arg1);
    public interface CeOverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CloudEventOverridesFluent<PingSourceSpecFluent.CeOverridesNested<N>> {

            public N and();
            public N endCeOverrides();    }


    public interface SinkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DestinationFluent<PingSourceSpecFluent.SinkNested<N>> {

            public N and();
            public N endSink();    }


}

==> knative-model-5.3.0-sources.jar: annotations/io/fabric8/knative/sources/v1beta1/PingSourceSpecFluent.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.StringBuffer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverrides;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesFluent;
import java.lang.Object;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesBuilder;
import java.lang.Boolean;
import java.util.Map;

public interface PingSourceSpecFluent<A extends PingSourceSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildCeOverrides instead.
 * @return The buildable object.
 */
@Deprecated public CloudEventOverrides getCeOverrides();
    public CloudEventOverrides buildCeOverrides();
    public A withCeOverrides(CloudEventOverrides ceOverrides);
    public Boolean hasCeOverrides();
    public PingSourceSpecFluent.CeOverridesNested<A> withNewCeOverrides();
    public PingSourceSpecFluent.CeOverridesNested<A> withNewCeOverridesLike(CloudEventOverrides item);
    public PingSourceSpecFluent.CeOverridesNested<A> editCeOverrides();
    public PingSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverrides();
    public PingSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverridesLike(CloudEventOverrides item);
    public String getJsonData();
    public A withJsonData(String jsonData);
    public Boolean hasJsonData();
    public A withNewJsonData(StringBuilder arg1);
    public A withNewJsonData(int[] arg1,int arg2,int arg3);
    public A withNewJsonData(char[] arg1);
    public A withNewJsonData(StringBuffer arg1);
    public A withNewJsonData(byte[] arg1,int arg2);
    public A withNewJsonData(byte[] arg1);
    public A withNewJsonData(char[] arg1,int arg2,int arg3);
    public A withNewJsonData(byte[] arg1,int arg2,int arg3);
    public A withNewJsonData(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewJsonData(String arg1);
    public String getSchedule();
    public A withSchedule(String schedule);
    public Boolean hasSchedule();
    public A withNewSchedule(StringBuilder arg1);
    public A withNewSchedule(int[] arg1,int arg2,int arg3);
    public A withNewSchedule(char[] arg1);
    public A withNewSchedule(StringBuffer arg1);
    public A withNewSchedule(byte[] arg1,int arg2);
    public A withNewSchedule(byte[] arg1);
    public A withNewSchedule(char[] arg1,int arg2,int arg3);
    public A withNewSchedule(byte[] arg1,int arg2,int arg3);
    public A withNewSchedule(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSchedule(String arg1);
    
/**
 * This method has been deprecated, please use method buildSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getSink();
    public Destination buildSink();
    public A withSink(Destination sink);
    public Boolean hasSink();
    public PingSourceSpecFluent.SinkNested<A> withNewSink();
    public PingSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
    public PingSourceSpecFluent.SinkNested<A> editSink();
    public PingSourceSpecFluent.SinkNested<A> editOrNewSink();
    public PingSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
    public String getTimezone();
    public A withTimezone(String timezone);
    public Boolean hasTimezone();
    public A withNewTimezone(StringBuilder arg1);
    public A withNewTimezone(int[] arg1,int arg2,int arg3);
    public A withNewTimezone(char[] arg1);
    public A withNewTimezone(StringBuffer arg1);
    public A withNewTimezone(byte[] arg1,int arg2);
    public A withNewTimezone(byte[] arg1);
    public A withNewTimezone(char[] arg1,int arg2,int arg3);
    public A withNewTimezone(byte[] arg1,int arg2,int arg3);
    public A withNewTimezone(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewTimezone(String arg1);
    public interface CeOverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CloudEventOverridesFluent<PingSourceSpecFluent.CeOverridesNested<N>> {

            public N and();
            public N endCeOverrides();    }


    public interface SinkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DestinationFluent<PingSourceSpecFluent.SinkNested<N>> {

            public N and();
            public N endSink();    }


}
